<?php
/**
 * Plugin Name: Custom Order Status Manager for WooCommerce
 * Plugin URI: https://wordpress.org/plugins/bp-custom-order-status-for-woocommerce/
 * Description: This plugin allows you to create, delete edit order statuses to better control the flow of your orders.
 * Version: 0.6
 * Author: Bright Plugins
 * Requires PHP: 7.2.0
 * Requires at least: 4.9
 * Tested up to: 6.0
 * WC tested up to: 6.6.1
 * WC requires at least: 3.9
 * Author URI: https://brightplugins.com
 * Text Domain: bp-custom-order-status
 * Domain Path: /languages
 */

defined( 'ABSPATH' ) || exit;

require_once __DIR__ . '/vendor/autoload.php';

// Define Values.
define( 'BVOS_PLUGIN_DIR', __DIR__ );
define( 'BVOS_TEMPLATE_PATH', untrailingslashit( plugin_dir_path( __FILE__ ) ) . '/templates/' );
define( 'BVOS_PLUGIN_FILE', __FILE__ );
define( 'BVOS_PLUGIN_BASE', plugin_basename( __FILE__ ) );
define( 'BVOS_PLUGIN_VER', '0.5' );

use Brightplugins_COS\Bootstrap;

// Check if WooCommerce is active
if ( in_array( 'woocommerce/woocommerce.php',
	apply_filters( 'active_plugins', get_option( 'active_plugins' ) )
	, true )
) {
	add_action( 'woocommerce_loaded', function () {

		$bootstrap = new Bootstrap();
		register_activation_hook( __FILE__, array( $bootstrap, 'on_activation' ) );
		register_deactivation_hook( __FILE__, [$bootstrap, 'onDeactivation'] );

	} );
} else {
	add_action( 'admin_notices', function () {
		$class   = 'notice notice-error';
		$message = __( 'Oops! looks like WooCommerce is disabled. Please, enable it in order to use BP Custom Order Status for WooCommerce.', 'bp-custom-order-status' );
		printf( '<div class="%1$s"><p>%2$s</p></div>', esc_attr( $class ), esc_html( $message ) );
	} );
}

/**
 * strtolower for status slug
 *
 */
function bpos_cb_strtolower_status_slug() {

	$status_slug = wc_strtolower( get_post_meta( get_the_ID(), 'status_slug', true ) );

	update_post_meta( get_the_ID(), 'status_slug', $status_slug );
	echo '<style>.post-type-order_status #edit-slug-box{display:none}</style>';


}