<?php
namespace Brightplugins_COS;

class Cpt {

	public function __construct() {
		add_action( 'init', [$this, 'orderstatus_custom_post_register'] );
		add_action( 'admin_menu', [$this, 'add_order_status_menu'] );
		add_action( 'parent_file', [$this, 'wc_as_highlight'] );
		$this->status_meta_box();

	}
	
/**
 * Custom status options.
 *
 * @return void.
 */
	public function status_meta_box() {

		$prefix = 'wcbv-order-status-new';

		// Create a metabox
		\CSF::createMetabox( $prefix, array(
			'title'              => __( 'Order Status Settings', 'bp-custom-order-status' ),
			'post_type'          => 'order_status',
			'data_type'          => 'unserialize',
			'context'            => 'normal',
			'priority'           => 'default',
			'exclude_post_types' => array(),

			'show_restore'       => false,
			'enqueue_webfont'    => true,
			'async_webfont'      => false,
			'output_css'         => true,
			'nav'                => 'normal',

			'class'              => '',
		) );

		\CSF::createSection( $prefix, array(
			'fields' => array(
				
				array(
					'id'       => 'status_slug',
					'type'     => 'text',
					'title'    => 'Slug',
					'subtitle' => __( '* Without wc- prefix', 'bp-custom-order-status' ),
				),
				array(
					'id'    => 'status_icon',
					'type'  => 'icon',
					'title' => __( 'Status Icon', 'bp-custom-order-status' ),
				),

				array(
					'id'      => 'text_color',
					'default' => '#000000',
					'type'    => 'color',
					'title'   => __( 'Color', 'bp-custom-order-status' ),
				),

				array(
					'id'      => 'is_status_paid',
					'type'    => 'checkbox',
					'title'   => __( 'Is a paid Status', 'bp-custom-order-status' ),
					'label'   => __( 'Check if order on this status has been Paid', 'bp-custom-order-status' ),
					'default' => '0',
				),
				array(
					'id'      => '_enable_action_status',
					'type'    => 'checkbox',
					'title'   => __( 'Add to actions on orders page', 'bp-custom-order-status' ),
					'label'   => __( 'Add to actions', 'bp-custom-order-status' ),
					'default' => '0',
				),
				array(
					'id'      => '_enable_bulk',
					'type'    => 'checkbox',
					'title'   => __( 'Add to bulk actions list', 'bp-custom-order-status' ),
					'label'   => __( 'Check this to add this order status to the Orders list table Bulk Actions list.', 'bp-custom-order-status' ),
					'default' => '0',
				),
				array(
					'id'    => '_enable_email',
					'type'  => 'checkbox',
					'title' => __( 'Enable Email Notification', 'bp-custom-order-status' ),
					'label' => __( 'Check this if you want notify by email when order status change to this status', 'bp-custom-order-status' ),

				),
				array(
					'id'      => '_email_type',
					'type'    => 'select',
					'title'   => __( 'Email recipient', 'bp-custom-order-status' ),
					'default' => 'admin',
					'options' => array(
						'admin'    => 'Admin',
						'customer' => 'Customer',
					),
				),
				array(
					'id'         => 'icon_code',
					//'subtitle' => __( 'For the chosen Status Icon', 'bp-custom-order-status' ),
					'type'       => 'text',
					'attributes' => ["hidden" => "true"],
					//'title' => __( 'Icon Code', 'bp-custom-order-status' ),
				),
				array(
					'type'     => 'callback',
					'function' => 'bpos_cb_strtolower_status_slug',
				),
			),
		) );

	}

	/**
	 * @param  $parent_file
	 * @return mixed
	 */
	public function wc_as_highlight( $parent_file ) {
		global $submenu_file, $current_screen;

		// Set correct active/current menu and submenu in the WordPress Admin menu for the "example_cpt" Add-New/Edit/List
		if ( $current_screen->post_type == 'order_status' ) {
			$submenu_file = 'edit.php?post_type=order_status';
			$parent_file  = 'woocommerce';
		}
		return $parent_file;
	}
	public function add_order_status_menu() {
		add_submenu_page( 'woocommerce', 'Order Status', 'Order Status', 'manage_woocommerce', 'edit.php?post_type=order_status' );
	}
	public function orderstatus_custom_post_register() {
		$labels = array(
			'name'               => _x( 'Order Status', 'custom_order_status', 'bp-custom-order-status' ),
			'singular_name'      => _x( 'Order Status', 'post type singular name', 'bp-custom-order-status' ),
			'menu_name'          => _x( 'Order Status', 'admin menu', 'bp-custom-order-status' ),
			'name_admin_bar'     => _x( 'Order Status', 'add new on admin bar', 'bp-custom-order-status' ),
			'add_new'            => _x( 'Add New', 'custom_order_status', 'bp-custom-order-status' ),
			'add_new_item'       => __( 'Add New  Order Status', 'bp-custom-order-status' ),
			'new_item'           => __( 'New  Order Status', 'bp-custom-order-status' ),
			'edit_item'          => __( 'Edit  Order Status', 'bp-custom-order-status' ),
			'view_item'          => __( 'View  Order Status', 'bp-custom-order-status' ),
			'all_items'          => __( 'All  Order Status', 'bp-custom-order-status' ),
			'search_items'       => __( 'Search  Order Status', 'bp-custom-order-status' ),
			'parent_item_colon'  => __( 'Parent  Order Status:', 'bp-custom-order-status' ),
			'not_found'          => __( 'No  Order Status found.', 'bp-custom-order-status' ),
			'not_found_in_trash' => __( 'No  Order Status found in Trash.', 'bp-custom-order-status' ),
		);

		$args = array(
			'labels'             => $labels,
			'description'        => __( 'Description.', 'bp-custom-order-status' ),
			'public'             => true,
			'publicly_queryable' => true,
			'show_ui'            => true,
			'show_in_menu'       => false,
			'query_var'          => true,
			'rewrite'            => array( 'slug' => 'order_status' ),
			'capability_type'    => 'post',
			'has_archive'        => true,
			'hierarchical'       => false,
			'supports'           => array( 'title' ),
		);

		register_post_type( 'order_status', $args );

	}

}
