<?php
namespace Brightplugins_COS;

class Settings {

	public function __construct() {

		add_action( 'admin_menu', array( $this, 'bp_admin_menu' ) );
		add_filter( "plugin_row_meta", [$this, 'pluginMetaLinks'], 20, 2 );
		add_action( 'plugins_loaded', [$this,'pluginOptions'],9999999 );

	}

	/**
	 * @param $settings_tabs
	 * @return mixed
	 */
	public static function add_settings_tab( $settings_tabs ) {
		$settings_tabs['settings_tab_demo'] = __( 'Custom Status Settings', 'bp-custom-order-status' );
		return $settings_tabs;
	}

	public function pluginOptions() {

		// Set a unique slug-like ID
		$prefix = 'wcbv_status_default';

		// Create options
		\CSF::createOptions( $prefix, array(
			'menu_title'      => 'Order Status Settings',
			'menu_slug'       => 'wcbv-order-status-setting',
			'framework_title' => 'Custom Order Status for WooCoomerce Settings ',
			'menu_type'       => 'submenu',
			'menu_parent'     => 'brightplugins',
			'nav'             => 'inline',
			'theme'           => 'light',
			'show_bar_menu'   => false,
		) );

		// Create a section
		\CSF::createSection( $prefix, array(
			'title'  => 'General Settings',
			'fields' => array(
				array(
					'id'      => 'orderstatus_default_status',
					'type'    => 'select',
					'title'   => __( 'Default order status', 'bp-custom-order-status' ),
					'default' => 'bpos_disabled',
					'options' => array_merge( array( 'bpos_disabled' => __( 'No changes', 'bp-custom-order-status' ) ), $this->wcbv_get_all_status() ),

				),
			),
		) );

		// Create a section
		\CSF::createSection( $prefix, array(
			'title'  => 'Payment Methods',
			'fields' => $this->getPaymentOptions(),
		) );

	}

	/**
	 * Option list for all payment methods
	 *
	 * @return array
	 */
	public function getPaymentOptions() {
		$payment_gateways = [];
		if ( is_admin() ) {
			$available_payment_gateways = WC()->payment_gateways->payment_gateways();
			$payment_gateways          = array();
			foreach ( $available_payment_gateways as $key => $gateway ) {
				$payment_gateways[] = array(
					'title'   => "Default status for: " . $gateway->title,
					'id'      => 'orderstatus_default_statusgateway_' . $key,
					'default' => 'bpos_disabled',
					'type'    => 'select',
					'desc'    => __( 'Order on this payment method will change to this status ', 'bp-custom-order-status' ),
					'options' => array_merge( array( 'bpos_disabled' => __( 'No changes', 'bp-custom-order-status' ) ), $this->wcbv_get_all_status() ),
				);
			}
	  }
		return $payment_gateways;
	}

	/**
	 * Get all woocommerce order status
	 *
	 * @return array
	 */
	public function wcbv_get_all_status() {
		$result   = array();
		$statuses = function_exists( 'wc_get_order_statuses' ) ? wc_get_order_statuses() : array();
		foreach ( $statuses as $status => $status_name ) {
			$result[substr( $status, 3 )] = $status_name;
		}
		return $result;
	}

	/**
	 * Add links to plugin's description in plugins table
	 *
	 * @param  array   $links Initial list of links.
	 * @param  string  $file  Basename of current plugin.
	 * @return array
	 */
	public function pluginMetaLinks( $links, $file ) {
		if ( $file !== BVOS_PLUGIN_BASE ) {
			return $links;
		}
		$support_link = '<a style="color:red;" target="_blank" href="https://brightplugins.com/support/">' . __( 'Support', 'bp-custom-order-status' ) . '</a>';

		$links[] = $support_link;

		return $links;
	}

	public function bp_admin_menu() {
		if ( empty( $GLOBALS['admin_page_hooks']['my_unique_slug'] ) ) {
			add_menu_page( 'Bright Plugins', 'Bright Plugins', '#manage_options', 'brightplugins', null, plugin_dir_url( __DIR__ ) . '/media/img/bp-logo-icon.png', 60 );
		}

		//do_action( 'bp_sub_menu' );
	}

}
